Module api

Module api 

Enums

GcArgs
GcWhat
GC operation codes (C: LUA_GC* constants)

Constants

LUA_IDENT

Functions

abs_index
arith
at_panic
call_k
check_stack
close_slot
compare
concat
copy
create_table
dump
gc
get_field
get_global
get_i
get_i_uservalue
get_i_value
Variant of get_i that accepts a pre-resolved table value instead of a stack index. Callers that invoke get_i repeatedly on the same table (e.g. the shift loops in table.remove / table.insert) should resolve the table once and use this function to avoid calling index_to_value on every iteration.
get_metatable
get_table
get_top
get_upvalue
is_cfunction
is_integer
is_number
is_string
is_userdata
len
load
lua_error
lua_type_at
new_userdata_uv
next
pcall_k
push_boolean
push_cclosure
push_fstring
push_integer
push_light_userdata
push_lstring
push_nil
push_number
push_string
push_thread
push_value
push_vfstring
raw_equal
raw_get
raw_get_i
raw_get_p
raw_len
raw_set
raw_set_i
raw_set_p
rotate
run_close_finalizers
Run every still-pending __gc finalizer at state close.
run_pending_finalizers
Phase-B __gc driver.
set_field
set_global
set_i
set_i_uservalue
set_i_value
Variant of set_i that accepts a pre-resolved table value instead of a stack index. Callers that invoke set_i repeatedly on the same table (e.g. the shift loops in table.remove / table.insert) should resolve the table once and use this function to avoid calling index_to_value on every iteration.
set_metatable
set_table
set_top
set_warn_f
setup_value
status
string_to_number
to_boolean
to_cfunction
to_close
to_integer_x
to_lua_string
to_number_x
to_pointer
to_thread
to_userdata
type_name
upvalue_id
upvalue_join
version
warning
xmove
Move the top n values from from’s stack onto to’s stack.