get_local

Function get_local 

pub fn get_local(
    state: &mut LuaState,
    ar: Option<&LuaDebug>,
    n: i32,
) -> Option<Vec<u8>>
Gets the name and value of local variable n in call frame ar->i_ci (or in the function at the top of the stack if ar is NULL). Pushes the value on the stack and returns its name, or returns None.