set_local

Function set_local 

pub fn set_local(state: &mut LuaState, ar: &LuaDebug, n: i32) -> Option<Vec<u8>>
Sets local variable n in call frame ar->i_ci to the value on top of the stack. Pops the value and returns the variable name, or returns None.