Pre-compiled Lua chunk serializer.
Translates reference/lua-5.4.7/src/ldump.c (230 lines, 9 functions + 1 public entry point).
Writes a LuaProto to a byte sink in the standard Lua 5.4 bytecode format.
Pre-compiled Lua chunk serializer.
Translates reference/lua-5.4.7/src/ldump.c (230 lines, 9 functions + 1 public entry point).
Writes a LuaProto to a byte sink in the standard Lua 5.4 bytecode format.