Module prelude

Module prelude 

Glob-imported by every module so the extension traits below resolve without each module having to list them individually.

Re-exports

pub use crate::state::LuaClosureExt;
pub use crate::state::LuaLClosureRefExt;
pub use crate::state::LuaProtoExt;
pub use crate::state::LuaStringRefExt;
pub use crate::state::LuaTableRefExt;
pub use crate::state::LuaTypeExt;
pub use crate::state::LuaUserDataRefExt;
pub use crate::state::LuaValueExt;
pub use crate::state::StackIdxExt;
pub use crate::vm::InstructionExt;
pub use crate::vm::OpCode;