pub struct ExternalRootKey { /* private fields */ }Expand description
Stable key for a value pinned in ExternalRootSet.
The generation is part of the key so a handle that has already unrooted its slot cannot accidentally observe a later handle’s value after slot reuse.