Enums
Constants
Functions
- abs_
index - arith
- at_
panic - call_k
- check_
stack - close_
slot - compare
- concat
- copy
- create_
table - dump
- gc
- get_
field - get_
global - get_i
- get_
i_ uservalue - get_
i_ value - Variant of
get_ithat accepts a pre-resolved table value instead of a stack index. Callers that invokeget_irepeatedly on the same table (e.g. the shift loops intable.remove/table.insert) should resolve the table once and use this function to avoid callingindex_to_valueon every iteration. - get_
metatable - get_
table - get_top
- get_
upvalue - is_
cfunction - is_
integer - is_
number - is_
string - is_
userdata - len
- load
- lua_
error - lua_
type_ at - new_
userdata_ uv - next
- pcall_k
- push_
boolean - push_
cclosure - push_
fstring - push_
integer - push_
light_ userdata - push_
lstring - push_
nil - push_
number - push_
string - push_
thread - push_
value - push_
vfstring - raw_
equal - raw_get
- raw_
get_ i - raw_
get_ p - raw_len
- raw_set
- raw_
set_ i - raw_
set_ p - rotate
- run_
close_ finalizers - Run every still-pending
__gcfinalizer at state close. - run_
pending_ finalizers - Phase-B
__gcdriver. - set_
field - set_
global - set_i
- set_
i_ uservalue - set_
i_ value - Variant of
set_ithat accepts a pre-resolved table value instead of a stack index. Callers that invokeset_irepeatedly on the same table (e.g. the shift loops intable.remove/table.insert) should resolve the table once and use this function to avoid callingindex_to_valueon every iteration. - set_
metatable - set_
table - set_top
- set_
warn_ f - setup_
value - status
- string_
to_ number - to_
boolean - to_
cfunction - to_
close - to_
integer_ x - to_
lua_ string - to_
number_ x - to_
pointer - to_
thread - to_
userdata - type_
name - upvalue_
id - upvalue_
join - version
- warning
- xmove
- Move the top
nvalues fromfrom’s stack ontoto’s stack.