get_hook_installed

Function get_hook_installed 

pub fn get_hook_installed(state: &LuaState) -> bool
Returns the current debug hook function, if any.

TODO(port): In C this returns a lua_Hook function pointer. In Rust the hook is a Box<dyn FnMut> and cannot be returned by raw reference without restructuring; for now returns a bool indicating whether a hook is installed.