get_stack

Function get_stack 

pub fn get_stack(state: &LuaState, level: i32, ar: &mut LuaDebug) -> bool
Fills ar with information about the call frame at depth level. Level 0 is the current running function, level 1 is the caller, etc. Returns true on success, false if the level is out of range.