pub struct LuaDebug {Show 17 fields
pub event: i32,
pub name: Option<Vec<u8>>,
pub namewhat: Option<&'static [u8]>,
pub what: Option<&'static [u8]>,
pub source: Option<Vec<u8>>,
pub srclen: usize,
pub currentline: i32,
pub linedefined: i32,
pub lastlinedefined: i32,
pub nups: u8,
pub nparams: u8,
pub isvararg: bool,
pub istailcall: bool,
pub ftransfer: u16,
pub ntransfer: u16,
pub short_src: [u8; 60],
pub i_ci: Option<CallInfoIdx>,
}Expand description
Debug introspection record.
C: lua_Debug in lua.h. Full mapping deferred to Phase E; this struct
holds only the fields that ldebug.c writes/reads.
Port note
name and namewhat are optional byte strings because in C they can be
NULL. source is owned here because we build it from Proto.source (a GcRef).
short_src matches C layout as a fixed array.
Fields
event: i32name: Option<Vec<u8>>namewhat: Option<&'static [u8]>what: Option<&'static [u8]>source: Option<Vec<u8>>srclen: usizecurrentline: i32linedefined: i32lastlinedefined: i32nups: u8nparams: u8isvararg: boolistailcall: boolftransfer: u16ntransfer: u16short_src: [u8; 60]i_ci: Option<CallInfoIdx>Trait Implementations