pub fn raw_arith(
state: &mut LuaState,
op: ArithOp,
p1: &LuaValue,
p2: &LuaValue,
res: &mut LuaValue,
) -> Result<bool, LuaError>Expand description
Attempts raw (no-metamethod) arithmetic on two Lua values.
Writes the result to res and returns true on success, false if the
operation cannot be performed with the given types (caller should invoke
a metamethod instead).
C: int luaO_rawarith (lua_State *L, int op, const TValue *p1, const TValue *p2, TValue *res)